/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.mode.metadata.persist.service.config.global;

import com.google.common.base.Strings;
import lombok.RequiredArgsConstructor;
import org.apache.shardingsphere.mode.persist.PersistRepository;
import org.apache.shardingsphere.mode.metadata.persist.node.GlobalNode;
import org.apache.shardingsphere.infra.util.yaml.YamlEngine;

import java.util.Properties;

/**
 * Properties persist service.
 */
@RequiredArgsConstructor
public final class PropertiesPersistService implements GlobalPersistService<Properties> {
    
    private final PersistRepository repository;
    
    @Override
    public void conditionalPersist(final Properties props) {
        if (!props.isEmpty() && !isExisted()) {
            persist(props);
        }
    }
    
    @Override
    public void persist(final Properties props) {
        repository.persist(GlobalNode.getPropsPath(), YamlEngine.marshal(props));
    }
    
    private boolean isExisted() {
        return !Strings.isNullOrEmpty(repository.getDirectly(GlobalNode.getPropsPath()));
    }
    
    @Override
    public Properties load() {
        return Strings.isNullOrEmpty(repository.getDirectly(GlobalNode.getPropsPath())) ? new Properties() : YamlEngine.unmarshal(repository.getDirectly(GlobalNode.getPropsPath()), Properties.class);
    }
}
